# GPU Cluster Capella

## Overview

The multi-GPU cluster `Capella` has been installed for AI-related computations and traditional
HPC simulations.

## Details

- 144 nodes, each with
    - 4 x NVIDIA H100-SXM5 Tensor Core-GPUs
    - 2 x AMD EPYC CPU 9334 (32 cores) @ 2.7 GHz, Multithreading disabled
    - 768 GB RAM (12 x 32 GB DDR5-4800 MT/s per socket)
    - 800 GB local storage on NVMe device at `/tmp`
- Login nodes: `login[1-2].capella.hpc.tu-dresden.de`
- Hostnames: `c[1-144].capella.hpc.tu-dresden.de`
- Operating system: Alma Linux 9.4

## Filesystems

Capella has a fast WEKAio file system mounted on `/data/cat`. It is only mounted on Capella and the
[Datamover nodes](../data_transfer/datamover.md).
It should be used as the main working file system on Capella.
Although all other [filesystems](../data_lifecycle/file_systems.md)
(`/home`, `/software`, `/data/horse`, `/data/walrus`, etc.) are also available.

### Modules

The easiest way is using the [module system](../software/modules.md).
All software available from the module system has been deliberately build for the cluster `Alpha`
i.e., with optimization for Zen4 (Genoa) microarchitecture and CUDA-support enabled.

To check the available modules for `Capella`, use the command

```console
marie@login.capella$ module spider <module_name>
```

??? example "Example: Searching and loading PyTorch"

    For example, to check which `PyTorch` versions are available you can invoke

    ```console
    marie@login.capella$ module spider PyTorch

    ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
     PyTorch: PyTorch/2.1.2-CUDA-12.1.1
    ------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------------
    Description:
      Tensors and Dynamic neural networks in Python with strong GPU acceleration. PyTorch is a deep learning framework that puts Python first.


    You will need to load all module(s) on any one of the lines below before the "PyTorch/2.1.2-CUDA-12.1.1" module is available to load.

      release/24.04  GCC/12.3.0  OpenMPI/4.1.5
 
    Help:
      Description
      ===========
      Tensors and Dynamic neural networks in Python with strong GPU acceleration.
      PyTorch is a deep learning framework that puts Python first.
      
      
      More information
      ================
       - Homepage: https://pytorch.org/
    ```

    ```console
    marie@login.capella$ python -c "import torch; print(torch.__version__); print(torch.cuda.is_available())"
    2.1.12
    True
    ```

### Python Virtual Environments

[Virtual environments](../software/python_virtual_environments.md) allow you to install
additional Python packages and create an isolated runtime environment. We recommend using
`virtualenv` for this purpose.

An example how to create an [python virtual environment with `torchvision` package](alpha_centauri.md#python-virtual-environments) is
 described for the GPU alpha cluster and is identical if you are using the Capella cluster.


!!! hint

    We recommend to use [workspaces](../data_lifecycle/workspaces.md) for your virtual environments.

